@@ -10,12 +10,12 @@ settingsfile = os.path.join(DATA_DIR,"presets.yml")
 configfiles = ["ytd.yml","ytd.yaml",".ytd"]
 processname = "yt-dlp"
 
-@mainfunction({},shield=True)
-def main(preset=None,url=None,new=None):
-	if new is None and preset is not None and url is not None:
+@mainfunction({'p':'preset','n':'new'},shield=True)
+def main(url=None,preset=None,new=None,**additionals):
+	if new is None and url is not None:
 
 		# no preset, dl here
-		if preset == ".":
+		if preset is None:
 			folder = os.getcwd()
 			options = {}
 			flags = []
@@ -47,10 +47,24 @@ def main(preset=None,url=None,new=None):
 				try:
 					with open(local_configfile,"r") as f:
 						localsettings = yaml.safe_load(f)
-						if "options" in localsettings: options.update(localsettings["options"])
-						if "flags" in localsettings: flags += localsettings["flags"]
+
+
+						# already loaded ones from lower directories take precedence
+						if "options" in localsettings:
+							loc_options = localsettings["options"]
+							# adjust relative paths from settings file
+							for o in loc_options:
+								if isinstance(loc_options[o],str) and loc_options[o].startswith("^"):
+									loc_options[o] = loc_options[o].replace("^",tmpfolder)
+							options = {**loc_options,**options}
+						if "flags" in localsettings:
+							loc_flags = localsettings["flags"]
+							flags += loc_flags
+
+
+
 						print("[ytd]\t",local_configfile)
-				except:
+				except FileNotFoundError:
 					pass
 
 			if os.path.dirname(tmpfolder) != tmpfolder:
@@ -59,6 +73,10 @@ def main(preset=None,url=None,new=None):
 				break
 
 		os.chdir(folder)
+
+		# add command-supplied options
+		options = {**options,**additionals}
+
 	#	print("The following options have been loaded from local configuration:")
 	#	for o in options:
 	#		print("   ",o)
